@@ -7,7 +7,7 @@ for dirpath, dirnames, files in os.walk('./'):
         if 'settings.py' in files:
             PATH_TO_SETTINGS = dirpath[2:] + '.settings'
 
-sys.path.append(str(Path(__file__).parent.parent.parent.parent.parent.parent.parent) + '/')
+sys.path.append(str(Path(__file__).parent.parent.parent.parent.parent.parent) + '/')
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", PATH_TO_SETTINGS)
 import django
 
